@@ -3,10 +3,10 @@ from collections import OrderedDict
 from django.conf import settings
 from django.views.generic import ListView
 
-from django_master.views import MasterContextMixin
+from django_master.views import MasterMixin
 
 
-class SettingsListView(ListView, MasterContextMixin):
+class SettingsListView(ListView, MasterMixin):
     template_name = 'django_master/settings.html'
     context_object_name = 'settings'
     menu_item = 'settings'
